@@ -1,6 +1,6 @@
 package Text::Minify::XS;
 
-# ABSTRACT: Simple text minification
+# ABSTRACT: remove indentation and trailing whitespace
 
 use v5.9.3;
 use strict;
@@ -10,12 +10,17 @@ require Exporter;
 require XSLoader;
 
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(minify);
+our @EXPORT_OK = qw(minify minify_utf8 minify_ascii);
 
-our $VERSION = 'v0.4.10'; # TRIAL
+our $VERSION = 'v0.5.3'; # TRIAL
 
 XSLoader::load( "Text::Minify::XS", $VERSION );
 
+{
+    no strict 'refs';
+    *minify_utf8 = \&minify;
+}
+
 1;
 
 __END__
@@ -26,11 +31,11 @@ __END__
 
 =head1 NAME
 
-Text::Minify::XS - Simple text minification
+Text::Minify::XS - remove indentation and trailing whitespace
 
 =head1 VERSION
 
-version v0.4.10
+version v0.5.3
 
 =head1 SYNOPSIS
 
@@ -38,6 +43,11 @@ version v0.4.10
 
   my $out = minify( $in );
 
+=head1 DESCRIPTION
+
+This is a simple and fast text minifier that removes quickly extra
+whitespace from multi-line UTF-8 text.
+
 =head1 EXPORTS
 
 None by default.
@@ -46,8 +56,8 @@ None by default.
 
   my $out = minify( $in );
 
-This is a quick-and-dirty text minifier that removes whitespace in a
-single pass.
+This is a quick-and-dirty text minifier that removes indentation and
+trailing whitespace from a multi-line text document in a single pass.
 
 It does the following:
 
@@ -74,15 +84,21 @@ and changes carriage returns to newlines.
 It does not recognise any form of markup, comments or text quoting.
 Nor does it remove extra whitespace in the middle of the line.
 
+Because it does not recognise any markup, newlines are removed since
+they may be significant.
+
+=head2 minify_utf8
+
+This is an alias for L</minify>.  It was added in v0.5.3.
+
+=head2 minify_ascii
+
+This is a version of L</minify> that works on ASCII text. It was added in v0.5.3.
+
+If you are only processing ASCII text, then it should be faster.
+
 =head1 KNOWN ISSUES
 
-=head2 Support for older Perl versions
-
-This module requires Perl v5.9.3 or newer.
-
-Pull requests to support older versions of Perl are welcome. See
-L</SOURCE>.
-
 =head2 Malformed UTF-8
 
 Malformed UTF-8 characters may be be mangled or omitted from the
@@ -168,7 +184,7 @@ Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020-2021 by Robert Rothenberg.
+This software is Copyright (c) 2020-2022 by Robert Rothenberg.
 
 This is free software, licensed under:
 
